==> jmb.async-0.1.tar.gz: jmb.async-0.1/jmb/async/models.py <==
# coding: utf-8
"""
Placeholder
"""

from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _
from celery.result import AsyncResult
from celery.states import state

from jmb.core.db.models import DateModel, UserModel, StatusModel

# http://celery.readthedocs.org/en/latest/reference/celery.states.html
# get them from cerey.states.ALL_STATES
CELERY_STATES = (
    ('RECEIVED', 'RECEIVED'),
    ('RETRY', 'RETRY'),
    ('REVOKED', 'REVOKED'),
    ('STARTED', 'STARTED'),
    ('PENDING', 'PENDING'),
    # PROGRESS is not in ALL_STATES but returned by res.status...
    # and referenced in docs as custom state.
    ('PROGRESS', 'PROGRESS'),  
    ('SUCCESS', 'SUCCESS'),
    ('FAILURE', 'FAILURE'),
)

###################################
## MODEL                          #
###################################
class Task(DateModel, UserModel):
    title = models.CharField(max_length=50)
    task_id = models.CharField(max_length=50)
    app_label = models.CharField(max_length=30, null=True, blank=True)
    status = models.CharField(max_length=10, choices=CELERY_STATES, null=True, blank=True)
    note = models.TextField()

    def get_result(self):
        return AsyncResult(self.task_id)
    
    def get_status(self, update=True):
        """return an updated status. Udate db if needed
        
        :arg update: boolean to update status in db
        """
        if state(self.status) <= state('FAILURE'):
           res = self.get_result()
           self.status = res.status
           if update:
               self.save()
           return res.status
        return self.status
    
    def get_progress_bar(self):
        res = self.get_result()
        status = self.get_status()
        if state(self.status) >= state('FAILURE'):
            bar_class = """
                readybar " aria-valuetransitiongoal="100" 
                style="width: 100%;" aria-valuenow="100
                """
        else:
            bar_class = 'jmbcelerybar'
        return """
                <div class="progress"><div id="%s" 
                status="%s" class=" bar six-sec-ease-in-out %s"
                role="progressbar" ></div></div>
            """ % (self.task_id, self.status, bar_class)
            
    get_progress_bar.short_description = _("Status")
    get_progress_bar.allow_tags = True
       
    class Meta(object):
       verbose_name = _('Task')
       verbose_name_plural = _('Tasks')

    def __unicode__(self):
       return self.title

# if settings.CMS_ENABLED:
#     import namespace.appname.model.cms.plugins
#     import namespace.appname.model.cms.app

==> jmb.async-0.3.1.tar.gz: jmb.async-0.3.1/jmb/async/models.py <==
# coding: utf-8
"""
Placeholder
"""

from django.conf import settings
from django.core.urlresolvers import reverse
from django.db import models
from django.utils.translation import ugettext_lazy as _

from celery.result import AsyncResult
from celery.states import state

from jmb.async.celeryapp import app as celery_app
from jmb.core.db.fields import HTMLField
from jmb.core.db.models import DateModel, UserModel, StatusModel

# http://celery.readthedocs.org/en/latest/reference/celery.states.html
# get them from cerey.states.ALL_STATES
CELERY_STATES = (
    ('RECEIVED', 'RECEIVED'),
    ('RETRY', 'RETRY'),
    ('REVOKED', 'REVOKED'),
    ('STARTED', 'STARTED'),
    ('PENDING', 'PENDING'),
    # PROGRESS is not in ALL_STATES but returned by res.status...
    # and referenced in docs as custom state.
    ('PROGRESS', 'PROGRESS'),  
    ('SUCCESS', 'SUCCESS'),
    ('FAILURE', 'FAILURE'),
)


###################################
## MODEL                          #
###################################
class Task(DateModel, UserModel):
    title = models.CharField(max_length=255, verbose_name=_('title'))
    task_id = models.CharField(max_length=50, verbose_name=_('task id'))
    app_label = models.CharField(max_length=255, null=True, blank=True, verbose_name=_('app label'))
    status = models.CharField(max_length=10, choices=CELERY_STATES, null=True, blank=True, verbose_name=_('status'))
    url = models.CharField(max_length=255, null=True, blank=True, verbose_name=_('url'))
    message = HTMLField(null=True, blank=True, verbose_name=_('message'))

    def get_result(self):
        return AsyncResult(self.task_id)
    
    def get_status(self, update=True):
        """return an updated status. Udate db if needed
        
        :arg update: boolean to update status in db
        """
        if state(self.status) <= state('FAILURE'):
            res = self.get_result()
            self.status = res.status
            if update:
                self.save()
            return res.status
        return self.status
    
    def get_progress_bar(self):
        res = self.get_result()
        status = self.get_status()
        if state(self.status) >= state('FAILURE'):
            bar_class = """
                readybar " aria-valuetransitiongoal="100" 
                style="width: 100%;" aria-valuenow="100
                """
        else:
            bar_class = 'jmbcelerybar'
        return """
                <div class="progress"><div id="%s" 
                status="%s" class=" bar six-sec-ease-in-out %s"
                role="progressbar" ></div></div>
            """ % (self.task_id, self.status, bar_class)
            
    get_progress_bar.short_description = _("Status")
    get_progress_bar.allow_tags = True
       
    class Meta(object):
        verbose_name = _('Task')
        verbose_name_plural = _('Tasks')

    def __unicode__(self):
        return self.title

# if settings.CMS_ENABLED:
#     import namespace.appname.model.cms.plugins
#     import namespace.appname.model.cms.app
